[Scummvm-git-logs] scummvm master -> 60be24d973e2a86493fd636fb152ffb31527275f

csnover csnover at users.noreply.github.com
Sat Oct 1 02:11:51 CEST 2016


This automated email contains information about 1 new commit which have been
pushed to the 'scummvm' repo located at https://github.com/scummvm/scummvm .

Summary:
60be24d973 SCI: Bump save game number to fix save game compatibility


Commit: 60be24d973e2a86493fd636fb152ffb31527275f
    https://github.com/scummvm/scummvm/commit/60be24d973e2a86493fd636fb152ffb31527275f
Author: Colin Snover (github.com at zetafleet.com)
Date: 2016-09-30T19:05:14-05:00

Commit Message:
SCI: Bump save game number to fix save game compatibility

Version 38 save games were added to the 1.9 release branch with
only changes to SCI32 cursor support; shortly thereafter, changes
to the general (SCI16+SCI32) save game metadata were committed to
master -- without bumping the save game version number. This
prevented SCI16 save games from loading correctly in 1.10pre, since
the engine expected that version 38 games would have this extra
metadata, but they don't.

Changed paths:
    engines/sci/engine/savegame.cpp
    engines/sci/engine/savegame.h



diff --git a/engines/sci/engine/savegame.cpp b/engines/sci/engine/savegame.cpp
index a238d76..20889f2 100644
--- a/engines/sci/engine/savegame.cpp
+++ b/engines/sci/engine/savegame.cpp
@@ -333,7 +333,7 @@ static void sync_SavegameMetadata(Common::Serializer &s, SavegameMetadata &obj)
 
 	// Some games require additional metadata to display their restore screens
 	// correctly
-	if (s.getVersion() >= 38) {
+	if (s.getVersion() >= 39) {
 		if (s.isSaving()) {
 			const reg_t *globals = g_sci->getEngineState()->variables[VAR_GLOBAL];
 			if (g_sci->getGameId() == GID_SHIVERS) {
diff --git a/engines/sci/engine/savegame.h b/engines/sci/engine/savegame.h
index 8c54f3b..873394a 100644
--- a/engines/sci/engine/savegame.h
+++ b/engines/sci/engine/savegame.h
@@ -37,7 +37,8 @@ struct EngineState;
  *
  * Version - new/changed feature
  * =============================
  *      38 - SCI32 cursor, accurate SCI32 arrays/strings, score metadata, avatar metadata
  *      37 - Segment entry data changed to pointers
  *      36 - SCI32 bitmap segment
  *      35 - SCI32 remap
@@ -63,7 +64,7 @@ struct EngineState;
  */
 
 enum {
-	CURRENT_SAVEGAME_VERSION = 38,
+	CURRENT_SAVEGAME_VERSION = 39,
 	MINIMUM_SAVEGAME_VERSION = 14
 };
 
@@ -37,7 +37,8 @@ struct EngineState;
  * Version - new/changed feature
  * =============================
- *      38 - SCI32 cursor, accurate SCI32 arrays/strings, score metadata, avatar metadata
+ *      39 - Accurate SCI32 arrays/strings, score metadata, avatar metadata
+ *      38 - SCI32 cursor
  *      37 - Segment entry data changed to pointers
  *      36 - SCI32 bitmap segment





More information about the Scummvm-git-logs mailing list